lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [thread-next>] [day] [month] [year] [list]
Date:	Mon, 08 Feb 2016 23:41:10 +0100
From:	"Rafael J. Wysocki" <rjw@...ysocki.net>
To:	Linux PM list <linux-pm@...r.kernel.org>
Cc:	Linux Kernel Mailing List <linux-kernel@...r.kernel.org>,
	Viresh Kumar <viresh.kumar@...aro.org>
Subject: [PATCH] cpufreq: governor: Rename skip_work to work_count

From: Rafael J. Wysocki <rafael.j.wysocki@...el.com>

The skip_work field in struct policy_dbs_info technically is a
counter, so give it a new name to reflect that.

No functional changes.

Signed-off-by: Rafael J. Wysocki <rafael.j.wysocki@...el.com>
---

On top of the bleeding-edge branch on linux-pm.git.

Thanks,
Rafael

---
 drivers/cpufreq/cpufreq_governor.c |   14 +++++++-------
 drivers/cpufreq/cpufreq_governor.h |    2 +-
 2 files changed, 8 insertions(+), 8 deletions(-)

Index: linux-pm/drivers/cpufreq/cpufreq_governor.h
===================================================================
--- linux-pm.orig/drivers/cpufreq/cpufreq_governor.h
+++ linux-pm/drivers/cpufreq/cpufreq_governor.h
@@ -149,7 +149,7 @@ struct policy_dbs_info {
 
 	u64 last_sample_time;
 	s64 sample_delay_ns;
-	atomic_t skip_work;
+	atomic_t work_count;
 	struct irq_work irq_work;
 	struct work_struct work;
 	/* dbs_data may be shared between multiple policy objects */

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ
Index: linux-pm/drivers/cpufreq/cpufreq_governor.c
===================================================================
--- linux-pm.orig/drivers/cpufreq/cpufreq_governor.c
+++ linux-pm/drivers/cpufreq/cpufreq_governor.c
@@ -196,16 +196,16 @@ static inline void gov_clear_update_util
 static void gov_cancel_work(struct policy_dbs_info *policy_dbs)
 {
 	/* Tell dbs_update_util_handler() to skip queuing up work items. */
-	atomic_inc(&policy_dbs->skip_work);
+	atomic_inc(&policy_dbs->work_count);
 	/*
 	 * If dbs_update_util_handler() is already running, it may not notice
 	 * the incremented skip_work, so wait for it to complete to prevent its
 	 * work item from being queued up after the cancel_work_sync() below.
 	 */
 	gov_clear_update_util(policy_dbs->policy);
 	irq_work_sync(&policy_dbs->irq_work);
 	cancel_work_sync(&policy_dbs->work);
-	atomic_set(&policy_dbs->skip_work, 0);
+	atomic_set(&policy_dbs->work_count, 0);
 }
 
 static void dbs_work_handler(struct work_struct *work)
@@ -234,7 +234,7 @@ static void dbs_work_handler(struct work
 	 * up using a stale sample delay value.
 	 */
 	smp_mb__before_atomic();
-	atomic_dec(&policy_dbs->skip_work);
+	atomic_dec(&policy_dbs->work_count);
 }
 
 static void dbs_irq_work(struct irq_work *irq_work)
@@ -266,7 +266,7 @@ static void dbs_update_util_handler(stru
 	 * - The governor is being stopped.
 	 * - It is too early (too little time from the previous sample).
 	 */
-	if (atomic_inc_return(&policy_dbs->skip_work) == 1) {
+	if (atomic_inc_return(&policy_dbs->work_count) == 1) {
 		u64 delta_ns;
 
 		delta_ns = time - policy_dbs->last_sample_time;
@@ -276,7 +276,7 @@ static void dbs_update_util_handler(stru
 			return;
 		}
 	}
-	atomic_dec(&policy_dbs->skip_work);
+	atomic_dec(&policy_dbs->work_count);
 }
 
 static void set_sampling_rate(struct dbs_data *dbs_data,
@@ -304,7 +304,7 @@ static struct policy_dbs_info *alloc_pol
 		return NULL;
 
 	mutex_init(&policy_dbs->timer_mutex);
-	atomic_set(&policy_dbs->skip_work, 0);
+	atomic_set(&policy_dbs->work_count, 0);
 	init_irq_work(&policy_dbs->irq_work, dbs_irq_work);
 	INIT_WORK(&policy_dbs->work, dbs_work_handler);
 
@@ -196,16 +196,16 @@ static inline void gov_clear_update_util
 	/*
 	 * If dbs_update_util_handler() is already running, it may not notice
-	 * the incremented skip_work, so wait for it to complete to prevent its
+	 * the incremented work_count, so wait for it to complete to prevent its
 	 * work item from being queued up after the cancel_work_sync() below.
 	 */